/*		 ITI-FG  Kernel module free public release
 *
 *		     Copyright (C) 1996-2000 GOM mbH.
 *	         Rebenring 33, 38106 Braunschweig, GERMANY
 *		            All rights reserved
 *
 * $Id: iticonfig.h,v 7.0.2.1 2000/12/04 14:56:07 cvs Exp $
 *
 */

#ifndef _ITICONFIG_H
#define _ITICONFIG_H

#ifdef __cplusplus
extern "C" {
#endif

/* function to readout config files */
int
read_config (const char*,	/* camera config file name */
	     union iti_dev_t*,	/* camera structure to fill in */
	     int,		/* board  \               */
	     int,		/* module - to search for */
	     int,		/* camera /               */
	     char*,		/* camera name */
	     char*);		/* fpga-file name */

#define	MAX_ENTRY_LENGTH	64	/* max size of camera/fpga-file name */

int
read_procfs (u_long*,		/* device driver version */
	     char*,		/* compilation date */
	     int*,		/* number of boards */
	     int[ITI_BOARDS_MAX]);
	     /* array of module types per board */
	     /* e.g. module[board] = ICP_AMVS/ICP_AMNO */

/* function to convert the PCDig 'exo'-files for fpga download */
int
convert_fpgafile (const char* config_file, const char* device_file);

/* return values for read_config/test_config/read_procfs/convert_fpgafile */
enum cnf_err_t
{
  ECNF_ERR,			/* place holder (no error) */
  EITI_ARG,			/* or more of the arguments are wrong */ 
  EITI_FMT,			/* the file format is not as we expect it */
  EITI_ENT,			/* the file to parse is not found */
  EITI_SYS,			/* error while system call (check errno) */
  EITI_OTH			/* all other unspecified errors */
};

#ifdef __CONFIG__
/* general type definition */

struct iti_cnf_flag_t
{
  char identifier[32];
  u_char value;
  int offset;
};

struct iti_cnf_flag_debug_t
{
  char reg_name[32];
  char meaning[64];
};

struct iti_cnf_enum_t
{
  char identifier[32];
  char parameter[32];
  u_char value;
  int offset;
};

struct iti_cnf_enum_debug_t
{
  char reg_name[32];
  char meaning[64];
};

struct iti_cnf_num_t
{
  char identifier[32];
};

struct iti_cnf_num_debug_t
{
  char reg_name[32];
  char meaning[64];
};

#define OFFSET(member)	offsetof(struct vs_cam_t, member)
const struct iti_cnf_flag_t vs_cnf_flag[] =
{
  "XTAL_Mode",			VS_CLKSRC_XTAL,		OFFSET(clksrc),
  "PLL_Mode",			VS_CLKSRC_PLL,		OFFSET(clksrc),
  "Interlaced",			VS_ILACE,		OFFSET(smode),
  "NonInterlaced",		VS_NON_ILACE,		OFFSET(smode),
  "LEN_Invert",			VS_LEN_LO,		OFFSET(lenpol),
  "LEN_NoInvert",		VS_LEN_HI,		OFFSET(lenpol),
  "FLD_Invert",			VS_FLD_INV,		OFFSET(fldpol),
  "FLD_NoInvert",		VS_FLD_NO_INV,		OFFSET(fldpol),
  "FEN_Invert",			VS_FEN_LO,		OFFSET(fenpol),
  "FEN_NoInvert",		VS_FEN_HI,		OFFSET(fenpol),
  "PCLK_Invert",		VS_PCLK_FA,		OFFSET(pclkpol),
  "PCLK_NoInvert",		VS_PCLK_RI,		OFFSET(pclkpol),
  "External_Pixel_Clock_Enable", 	VS_ENABLE,	OFFSET(eclken),
  "External_Pixel_Clock_Disable",	VS_DISABLE,	OFFSET(eclken),
  "Field_Sync_Enable",		VS_ENABLE,		OFFSET(fldsten),
  "Field_Sync_Disable",		VS_DISABLE,		OFFSET(fldsten),
  "Vertical_Sync_Enable",	VS_ENABLE,		OFFSET(vsten),
  "Vertical_Sync_Disable",	VS_DISABLE,		OFFSET(vsten),
  "Trigger_Gen_Enable",		VS_ENABLE,		OFFSET(trgen),
  "Trigger_Gen_Disable",	VS_DISABLE,		OFFSET(trgen),
  "Clamping_Enable",		VS_ENABLE,		OFFSET(cpen),
  "Clamping_Disable",		VS_DISABLE,		OFFSET(cpen),
  "Strobe_Polarity_Low",	VS_STRB_LO,		OFFSET(strbpol),
  "Strobe_Polarity_High",	VS_STRB_HI,		OFFSET(strbpol),
  '\0',				0,			0
};
#undef OFFSET

#ifdef DEBUG_ITIFG
const struct iti_cnf_flag_debug_t vs_cnf_flag_debug[] =
{
  "clksrc ",	"Internal crystal mode",
  "clksrc ",	"Phase-locked loop mode",
  "smode  ",	"Interlaced camera",
  "smode  ",	"Non-interlaced camera",
  "lenpol ",	"LEN input active low, invert",
  "lenpol ",	"LEN input active high, no-invert",
  "fldpol ",	"0=odd field, 1=even field, invert",
  "fldpol ",	"0=even field, 1=odd field, no-invert",
  "fenpol ",	"FEN input active low, invert",
  "fenpol ",	"FEN input active high, no-invert",
  "pclkpol",	"Sample on falling edge, invert",
  "pclkpol",	"Sample on rising edge, no-invert",
  "eclken ",	"half clock frequency to camera",
  "eclken ",	"full clock frequency to camera",
  "fldsten",	"FLD comes from sync stripper",
  "fldsten",	"FLD comes from timing source",
  "vsten  ",	"VBlank comes from sync stripper",
  "vsten  ",	"VBlank comes from timing source",
  "trgen  ",	"Enable trigger",
  "trgen  ",	"Diasable trigger",
  "cpen   ",	"Clamp enabled",
  "cpen   ",	"Clamp disabled",
  "strbpol",	"Strobe active low",
  "strbpol",	"Strobe active high"
};
#endif /* DEBUG_ITIFG */

#define OFFSET(member)	offsetof(struct dg_cam_t, member)
const struct iti_cnf_flag_t dg_cnf_flag[] =
{
  "CCLK_14.32MHz",		DG_F_14_32,	        OFFSET(fsel),
  "CCLK_16.26MHz",		DG_F_16_26,	        OFFSET(fsel),
  "CCLK_32.51MHz",		DG_F_32_51,	        OFFSET(fsel),
  "CCLK_25.18MHz",		DG_F_25_18_I,	        OFFSET(fsel),
  "CCLK_28.32MHz",		DG_F_28_32_I,	        OFFSET(fsel),
  "CCLK_24.00MHz",		DG_F_24_00,	        OFFSET(fsel),
  "CCLK_40.00MHz",		DG_F_40_00,	        OFFSET(fsel),
  "CCLK_36.00MHz",		DG_F_36_00,	        OFFSET(fsel),
  "CCLK_44.90MHz",		DG_F_44_90,	        OFFSET(fsel),
  "CCLK_50.00MHz",		DG_F_50_00,	        OFFSET(fsel),
  "CCLK_Div1",			DG_D_1,		        OFFSET(clkdiv),
  "CCLK_Div2",			DG_D_2,		        OFFSET(clkdiv),
  "CCLK_Div4",			DG_D_4,		        OFFSET(clkdiv),
  "CCLK_Div8",			DG_D_8,		        OFFSET(clkdiv),
  "CCLK_Div16",			DG_D_16,	        OFFSET(clkdiv),
  "CCLK_Div32",			DG_D_32,	        OFFSET(clkdiv),
  "CCLK_Div64",			DG_D_64,	        OFFSET(clkdiv),
  "CCLK_Div128",		DG_D_128,	        OFFSET(clkdiv),
  "Xillix_Mode_Enable",		DG_ENABLE,	        OFFSET(xillen),
  "Xillix_Mode_Disable",	DG_DISABLE,	        OFFSET(xillen),
  "PCLK_Invert",		DG_PCLK_FA,	        OFFSET(pclkpol),
  "PCLK_NoInvert",		DG_PCLK_RI,	        OFFSET(pclkpol),
  "LEN_Invert",			DG_LEN_FA,	        OFFSET(lenpol),
  "LEN_NoInvert",		DG_LEN_RI,	        OFFSET(lenpol),
  "FEN_Invert",			DG_FEN_FA,	        OFFSET(fenpol),
  "FEN_NoInvert",		DG_FEN_RI,	        OFFSET(fenpol),
  "FLD_Invert",			DG_FLD_LO,	        OFFSET(fldpol),
  "FLD_NoInvert",		DG_FLD_HI,	        OFFSET(fldpol),
  "Area_Scan",			DG_AREA_SCAN,	        OFFSET(smode),
  "Line_Scan",			DG_LINE_SCAN,	        OFFSET(smode),
  "Interlaced",			DG_ILACE,	        OFFSET(ilmode),
  "NonInterlaced",		DG_NON_ILACE,	        OFFSET(ilmode),
  "LEN_Small",			DG_LEN_SMALL,	        OFFSET(lensm),
  "LEN_Wide",			DG_LEN_WIDE,	        OFFSET(lensm),
  "LineMiss_Mode",		DG_COMPAT_ICP,	        OFFSET(nolmiss),
  "No_LineMiss_Mode",		DG_COMPAT_MFG,	        OFFSET(nolmiss),
  "FIFO_Reset_Mode",		DG_FIFO_RESET,	        OFFSET(lvar),
  "Normal_FIFO_Mode",		DG_FIFO_NORMAL,	        OFFSET(lvar),
  "EXSCLK_14.32_Div2",		DG_C_7_16_M,	        OFFSET(exclk),
  "EXSCLK_14.32_Div8",		DG_C_1_79_M,	        OFFSET(exclk),
  "EXSCLK_14.32_Div32",		DG_C_447_5_k,	        OFFSET(exclk),
  "EXSCLK_14.32_Div128",	DG_C_112_k,	        OFFSET(exclk),
  "EXSCLK_14.32_Div512",	DG_C_28_k,	        OFFSET(exclk),
  "EXSCLK_14.32_Div2048",	DG_C_7_k,	        OFFSET(exclk),
  "EXSync_Counter_Enable",	DG_ENABLE,	        OFFSET(exsen),
  "EXSync_Counter_Disable",	DG_DISABLE,	        OFFSET(exsen),
  "EXSYNC_Pulse_Active_High",	DG_EXS_HI,	        OFFSET(expol),
  "EXSYNC_Pulse_Active_Low",	DG_EXS_LO,	        OFFSET(expol),
  "PRI_Enable",			DG_ENABLE,	        OFFSET(prien),
  "PRI_Disable",		DG_DISABLE,	        OFFSET(prien),
  "PRI_Active_High",		DG_PRI_HI,	        OFFSET(prip),
  "PRI_Active_Low",		DG_PRI_LO,	        OFFSET(prip),
  "Pixel_Size_8",		DG_PSIZE_8,	        OFFSET(psize),
  "Pixel_Size_10",		DG_PSIZE_10,	        OFFSET(psize),
  "Pixel_Size_12",		DG_PSIZE_12,	        OFFSET(psize),
  "Pixel_Size_16",		DG_PSIZE_16,	        OFFSET(psize),
  "Interleaved_Pixels",		DG_ILEAVE,	        OFFSET(ilpixel),
  "NonInterleaved_Pixels",	DG_NON_ILEAVE,	        OFFSET(ilpixel),
  "Trigger_Gen_Enable",		DG_ENABLE,	        OFFSET(trigen),
  "Trigger_Gen_Disable",	DG_DISABLE,	        OFFSET(trigen),
  '\0',				0,		        0
};
#undef OFFSET

#ifdef DEBUG_ITIFG
const struct iti_cnf_flag_debug_t dg_cnf_flag_debug[] =
{
  "fsel   ",	"f = 14.32 MHz",
  "fsel   ",	"f = 16.26 MHz",
  "fsel   ",	"f = 32.51 MHz",
  "fsel   ",	"f = 25.18 MHz",
  "fsel   ",	"f = 28.32 MHz",
  "fsel   ",	"f = 24.00 MHz",
  "fsel   ",	"f = 40.00 MHz",
  "fsel   ",	"f = 36.00 MHz",
  "fsel   ",	"f = 44.90 MHz",
  "fsel   ",	"f = 50.00 MHz",
  "clkdiv ",	"f / 1",
  "clkdiv ",	"f / 2",
  "clkdiv ",	"f / 4",
  "clkdiv ",	"f / 8",
  "clkdiv ",	"f / 16",
  "clkdiv ",	"f / 32",
  "clkdiv ",	"f / 64",
  "clkdiv ",	"f / 128",
  "xillen ",	"Xillix mode enable",
  "xillen ",	"Xillix mode disable",
  "pclkpol",	"Sample on falling edge, invert",
  "pclkpol",	"Sample on rising edge, no-invert",
  "lenpol ",	"LEN input active low, invert",
  "lenpol ",	"LEN input active high, no-invert",
  "fenpol ",	"FEN input active low, invert",
  "fenpol ",	"FEN input active high, no-invert",
  "fldpol ",	"0=odd field, 1=even field, invert",
  "fldpol ",	"0=even field, 1=odd field, no-invert",
  "smode  ",	"Area scan mode",
  "smode  ",	"Line scan mode",
  "ilmode ",	"Interlaced camera",
  "ilmode ",	"Non-interlaced camera",
  "lensm  ",	"LEN is smaller then PCLK",
  "lensm  ",	"LEN is grater then PCLK",
  "nolmiss",	"Two lines inserted (ICP)",
  "nolmiss",	"No lines inserted (MFG)",
  "lvar   ",	"Reset FIFO every FEN",
  "lvar   ",	"Normal FIFO operation",
  "exclk  ",	"t = 140ns (7.16 MHz)",
  "exclk  ",	"t = 558.6ns (1.79 MHz)",
  "exclk  ",	"t = 2.23us (447.5 kHz)",
  "exclk  ",	"t = 8.93us (112 kHz)",
  "exclk  ",	"t = 35.7us (28 kHz)",
  "exclk  ",	"t = 142us (7 kHz)",
  "exsen  ",	"External sync counter enabled",
  "exsen  ",	"External sync counter disabled",
  "exspol ",	"EXSYNC goes high when triggered",
  "exspol ",	"EXSYNC goes low when triggered",
  "prien  ",	"Programmable integration enabled",
  "prien  ",	"Programmable integaration disabled",
  "prip   ",	"PRIP output asserted low (always or inactive)",
  "prip   ",	"PRIP output asserted high (always or inactive)",
  "psize  ",	"Input pixel size 8 bit (256 LUT pages)",
  "psize  ",	"Input pixel size 10 bit (64 LUT pages)",
  "psize  ",	"Input pixel size 12 bit (16 LUT pages)",
  "psize  ",	"Input pixel size 16 bit (1 LUT page)",
  "ilpixel",	"Interleaved pixel mode",
  "ilpixel",	"Non-interleaved pixel mode",
  "trigen ",	"Trigger enabled",
  "trigen ",	"Trigger disabled"
};
#endif /* DEBUG_ITIFG */

#define OFFSET(member)	offsetof(struct pv_cam_t, member)
const struct iti_cnf_flag_t pv_cnf_flag[] =
{
  "HSync_Pol_Lo",		PV_HS_ACT_LOW,		OFFSET(hsyncpol),
  "HSync_Pol_Hi",		PV_HS_ACT_HIGH,		OFFSET(hsyncpol),
  "VSync_Pol_Lo",		PV_VS_ACT_LOW,		OFFSET(vsyncpol),
  "VSync_Pol_Hi",		PV_HS_ACT_HIGH,		OFFSET(vsyncpol),
  "LEN_Polarity_Hi",		PV_LP_ACT_HIGH,		OFFSET(lenpol),
  "LEN_Polarity_Lo",		PV_LP_ACT_LOW,		OFFSET(lenpol),
  "FEN_Polarity_Hi",		PV_FP_ACT_HIGH,		OFFSET(fenpol),
  "FEN_Polarity_Lo",		PV_FP_ACT_LOW,		OFFSET(fenpol),
  "FRST_Vsync_Disable",		PV_DISABLE,		OFFSET(frstonv),
  "FRST_Vsync_Enable",		PV_ENABLE,		OFFSET(frstonv),
  "FRST_Disable",		PV_DISABLE,		OFFSET(frstmd),
  "FRST_Enable",		PV_ENABLE,		OFFSET(frstmd),
  "FRST_Active_Hi",		PV_FR_ACT_HIGH,		OFFSET(frstpol),
  "FRST_Active_Lo",		PV_FR_ACT_LOW,		OFFSET(frstpol),
  "FRST_FROFF_Period",		PV_FRST_FROFF,		OFFSET(frstsz),
  "FRST_One_Line",		PV_FRST_LINE,		OFFSET(frstsz),
  "PTG_HSYNC_Select",		PV_HSYNC_OUT,		OFFSET(syncsel),
  "PTG_CSYNC_Select",		PV_CSYNC_OUT,		OFFSET(syncsel),
  "CHSYNCEN_Enable",		PV_CHSYNC_EN,		OFFSET(chsyncen),
  "CHSYNCEN_Disable",		PV_CHSYNC_DIS,		OFFSET(chsyncen),
  "VSYNCEN_Enable",		PV_VSYNC_EN,		OFFSET(vsyncen),
  "VSYNCEN_Disable",		PV_VSYNC_DIS,		OFFSET(vsyncen),
  "PLL_Mode",			PV_CLKSRC_PLL,		OFFSET(clksrc),
  "XTAL_Mode",			PV_CLKSRC_XTAL,		OFFSET(clksrc),
  "LPF_Disable",		PV_LPF_BYPASS,		OFFSET(lpfsel),
  "LPF_Enable",			PV_LPF_6_0,		OFFSET(lpfsel),
  "VSCAN_Disable",		PV_DISABLE,		OFFSET(vscan),
  "VSCAN_Enable",		PV_ENABLE,		OFFSET(vscan),
  "Scale_1",			PV_SCALE_1_0,		OFFSET(iscale),
  "Scale_1.5",			PV_SCALE_1_5,		OFFSET(iscale),
  "VClk_Normal",		PV_CP_ACT_HIGH,		OFFSET(vclkpol),
  "VClk_Inverted",		PV_CP_ACT_LOW,		OFFSET(vclkpol),
  "NonInterlaced",		PV_NON_ILACE,		OFFSET(smode),
  "Interlaced",			PV_ILACE,		OFFSET(smode),
  "FLDSHFT_Disable",		PV_DISABLE,		OFFSET(fldshft),
  "FLDSHFT_Enable",		PV_ENABLE,		OFFSET(fldshft),
  "Trig_Disable",		PV_DISABLE,		OFFSET(trigen),
  "Trig_Enable",		PV_ENABLE,		OFFSET(trigen),
  "Ext_Trigger",		PV_TRIG_EXT,		OFFSET(trigsrc),
  "SW_Trigger",			PV_TRIG_SOFT,		OFFSET(trigsrc),
  "Trigger_Active_Lo",		PV_TP_ACT_LOW,		OFFSET(trigpol),
  "Trigger_Active_Hi",		PV_TP_ACT_HIGH,		OFFSET(trigpol),
  "Strobe_Slow",		PV_STRBMD_SLOW,		OFFSET(strbmd),
  "Strobe_Fast",		PV_STRBMD_FAST,		OFFSET(strbmd),
  "Strobe_Disable",		PV_DISABLE,		OFFSET(strben),
  "Strobe_Enable",		PV_ENABLE,		OFFSET(strben),
  "Strobe_Active_Hi",		PV_SP_ACT_HIGH,		OFFSET(strbpol),
  "Strobe_Active_Lo",		PV_SP_ACT_LOW,		OFFSET(strbpol),
  "Skip_Field_Disable",		PV_DISABLE,		OFFSET(skpfldmd),
  "Skip_Field_Enable",		PV_ENABLE,		OFFSET(skpfldmd),
  "Clamp_On_LEN_Fall",		PV_CLMP_INVERT,		OFFSET(pclmpol),
  "Clamp_On_LEN_Rise",		PV_CLMP_NO_INV,		OFFSET(pclmpol),
  "Clamp_Src_Sync_Strip",	PV_CLMP_STRIP,		OFFSET(pclmpol),
  "Clamp_Src_Prog",		PV_CLMP_PROG,		OFFSET(pclmpol),
  '\0',				0,			0
};
#undef OFFSET

#define OFFSET(member)	offsetof(struct vs_cam_t, member)
const struct iti_cnf_enum_t vs_cnf_enum[] =
{
  "Timing_Option",		"RS170_10.00",
  VS_T_0_10_00_RS170,		OFFSET(tsel),
  "Timing_Option",		"MC1000P_20.00",
  VS_T_1_20_00_MC1000P,		OFFSET(tsel),
  "Timing_Option",		"RS170_12.28",
  VS_T_0_12_28_RS170,		OFFSET(tsel),
  "Timing_Option",		"RS170_14.32",
  VS_T_0_14_32_RS170,		OFFSET(tsel),
  "Timing_Option",		"CCIR_10.00",
  VS_T_0_10_00_CCIR,		OFFSET(tsel),
  "Timing_Option",		"CCIR_15.00",
  VS_T_0_15_00_CCIR,		OFFSET(tsel),
  "Timing_Option",		"CCIR_14.18",
  VS_T_0_14_18_CCIR,		OFFSET(tsel),
  "Timing_Option",		"Alternate_0",
  VS_T_0_10_00_RS170,		OFFSET(tsel),
  "Timing_Option",		"Alternate_1",
  VS_T_1_20_00_MC1000P,		OFFSET(tsel),
  "Timing_Option",		"Alternate_2",
  VS_T_0_12_28_RS170,		OFFSET(tsel),
  "Timing_Option",		"Alternate_3",
  VS_T_0_14_32_RS170,		OFFSET(tsel),
  "Timing_Option",		"Alternate_4",
  VS_T_0_10_00_CCIR,		OFFSET(tsel),
  "Timing_Option",		"Alternate_6",
  VS_T_0_15_00_CCIR,		OFFSET(tsel),
  "Timing_Option",		"Alternate_7",
  VS_T_0_14_18_CCIR,		OFFSET(tsel),
  "Filter_Type",		"LPF_3.0",
  VS_LPF_3_0,			OFFSET(lpfsel),
  "Filter_Type",		"LPF_4.3",
  VS_LPF_4_3,			OFFSET(lpfsel),
  "Filter_Type",		"LPF_6.5",
  VS_LPF_6_5,			OFFSET(lpfsel),
  "Filter_Type",		"LPF_12.0",
  VS_LPF_12_0,			OFFSET(lpfsel),
  "Video_Prescale",		"Scale_1.0",
  VS_SCALE_1_0,			OFFSET(iscale),
  "Video_Prescale",		"Scale_1.5",
  VS_SCALE_1_5,			OFFSET(iscale),
  "Video_Prescale",		"Scale_0.5",
  VS_SCALE_0_5,			OFFSET(iscale),
  "Video_Prescale",		"Scale_0.75",
  VS_SCALE_0_75,		OFFSET(iscale),
  "Window_Timing_Source",	"Standard_Timing_Generator",
  VS_TSRC_STD,			OFFSET(tsrc),
  "Window_Timing_Source",	"External_Timing_Port_0",
  VS_TSRC_EXT0,			OFFSET(tsrc),
  "Window_Timing_Source",	"External_Timing_Port_1",
  VS_TSRC_EXT1,			OFFSET(tsrc),
  "Window_Timing_Source",	"External_Timing_Port_0_1",
  VS_TSRC_DIF,			OFFSET(tsrc),
  "Trigger_Source",		"External",
  VS_TRIG_EXT,			OFFSET(trgsrc),
  "Trigger_Source",		"Software",
  VS_TRIG_SOFT,			OFFSET(trgsrc),
  "Frame_Reset_Mode",		"Low_Line",
  VS_FMODE_LOW_LINE,		OFFSET(fmode),
  "Frame_Reset_Mode",		"Low_VB",
  VS_FMODE_LOW_VB,		OFFSET(fmode),
  "Trigger_Mode",		"Trigger_On_Slow_Strobe",
  VS_TMODE_SLOW_STROBE,		OFFSET(tmode),
  "Trigger_Mode",		"Frame_Reset",
  VS_TMODE_FRAME_RESET,		OFFSET(tmode),
  "Trigger_Mode",		"Line_Scan",
  VS_TMODE_LINE_SCAN,		OFFSET(tmode),
  "Trigger_Mode",		"Trigger_On_Frame_Fast_Strobe",
  VS_TMODE_FAST_STROBE,		OFFSET(tmode),
  "Clamping_Source",		"Program_Clamp",
  VS_CPSRC_PROG,		OFFSET(cpsrc),
  "Clamping_Source",		"Auto_Clamp",
  VS_CPSRC_AUTO,		OFFSET(cpsrc),
  "Strobe_Source",		"Strobe_2",
  VS_STRB_2,			OFFSET(strbsel),
  "Strobe_Source",		"Strobe_1",
  VS_STRB_1,			OFFSET(strbsel),
  '\0',				'\0',
  0,				0
};
#undef OFFSET

#ifdef DEBUG_ITIFG
const struct iti_cnf_enum_debug_t vs_cnf_enum_debug[] =
{
  "tsel   ",	"f = 10 MHz (RS170)",
  "tsel   ",	"f = 20 MHz (MC1000P)",
  "tsel   ",	"f = 12.28 MHz (RS170)",
  "tsel   ",	"f = 14.32 MHz (RS170)",
  "tsel   ",	"f = 10.00 MHz (CCIR)",
  "tsel   ",	"f = 15.00 MHz (CCIR)",
  "tsel   ",	"f = 14.18 MHz (CCIR)",
  "tsel   ",	"f = 10 MHz (RS170)",
  "tsel   ",	"f = 20 MHz (MC1000P)",
  "tsel   ",	"f = 12.28 MHz (RS170)",
  "tsel   ",	"f = 14.32 MHz (RS170)",
  "tsel   ",	"f = 10.00 MHz (CCIR)",
  "tsel   ",	"f = 15.00 MHz (CCIR)",
  "tsel   ",	"f = 14.18 MHz (CCIR)",
  "lpfsel ",	"3.0 MHz -3dB bandwidth",
  "lpfsel ",	"4.3 MHz -3dB bandwidth",
  "lpfsel ",	"6.5 MHz -3dB bandwidth",
  "lpfsel ",	"12.0 MHz -3dB bandwidth",
  "iscale ",	"Scale video by 1.0",
  "iscale ",	"Scale video by 1.5",
  "iscale ",	"Scale video by 0.5",
  "iscale ",	"Scale video by 0.75",
  "tsrc   ",	"Standard timing generator",
  "tsrc   ",	"External timing 0",
  "tsrc   ",	"Extern timing 1",
  "tsrc   ",	"External differential timing",
  "trgsrc ",	"Enable external trigger",
  "trgsrc ",	"Enable software trigger",
  "fmode  ",	"Frame reset low one line",
  "fmode  ",	"Frame Reset low one v-blank",
  "tmode  ",	"Trigger on frame - slow strobe",
  "tmode  ",	"Frame reset",
  "tmode  ",	"Line scan",
  "tmode  ",	"Trigger on frame - fast strobe",
  "cpsrc  ",	"Programmable clamp pulse enabled",
  "cpsrc  ",	"Automatic clamp pulse enabled",
  "strbsel",	"Strobe 2 output enabled",
  "strbsel",	"Strobe 1 output enabled"
};
#endif /* DEBUG_ITIFG */

#define OFFSET(member)	offsetof(struct dg_cam_t, member)
const struct iti_cnf_enum_t dg_cnf_enum[] =
{
  "ExtSync_Mode",		"Disabled",
  DG_FREE_RUN,			OFFSET(extmd),
  "ExtSync_Mode",		"FreeRun",
  DG_FREE_RUN,			OFFSET(extmd),
  "ExtSync_Mode",		"Ext_Trigger",
  DG_EXT_TRIG,			OFFSET(extmd),
  "ExtSync_Mode",		"SW_Trigger",
  DG_SOFT_TRIG,			OFFSET(extmd),
  "ExtSync_Mode",		"FEN_Trigger",
  DG_VB_TRIG,			OFFSET(extmd),
  "AM_OutputA",			"High_Byte",
  DG_MUXA_HI,			OFFSET(muxa),
  "AM_OutputA",			"Low_Byte",
  DG_MUXA_LO,			OFFSET(muxa),
  "AM_OutputB",			"High_Byte",
  DG_MUXB_HI,			OFFSET(muxb),
  "AM_OutputB",			"Low_Byte",
  DG_MUXB_LO,			OFFSET(muxb),
  "AM_OutputC",			"High_Byte",
  DG_MUXC_HI,			OFFSET(muxc),
  "AM_OutputC",			"Low_Byte",
  DG_MUXC_LO,			OFFSET(muxc),
  "Trigger_Source",		"Software",
  DG_TRIG_SOFT,			OFFSET(trigsrc),
  "Trigger_Source",		"External",
  DG_TRIG_EXT,			OFFSET(trigsrc),
  '\0',				'\0',
  0,				0
};
#undef OFFSET

#ifdef DEBUG_ITIFG
const struct iti_cnf_enum_debug_t dg_cnf_enum_debug[] =
{
  "extmd  ",	"EXSYNC triggers itself",
  "extmd  ",	"EXSYNC triggers itself",
  "extmd  ",	"EXSYNC counter starts with external trigger",
  "extmd  ",	"EXSYNC counter starts with software trigger",
  "extmd  ",	"EXSYNC counter starts with v-blank",
  "muxa   ",	"High byte of input LUT to AMOutA",
  "muxa   ",	"Low byte of input LUT to AMOutA",
  "muxb   ",	"High byte of input LUT to AMOutB",
  "muxb   ",	"Low byte of input LUT to AMOutB",
  "muxc   ",	"High byte of input LUT to AMOutC",
  "muxc   ",	"Low byte of input LUT to AMOutC",
  "trigsrc",	"Trigger from camera connector",
  "trigsrc",	"Trigger from software"
};
#endif /* DEBUG_ITIFG */

#define OFFSET(member)	offsetof(struct pcd_cam_t, member)
const struct iti_cnf_enum_t pcd_cnf_enum[] =
{
  /* single */
  "LEN_SYNC",			"SYNC",
  PCD_LEN_SYNC,			OFFSET(lensync),
  "LEN_SYNC",			"ASYNC",
  PCD_LEN_ASYNC,		OFFSET(lensync),
  "LEN_POLARITY",		"FALLING_EDGE",
  PCD_LEN_ACT_LOW,		OFFSET(lenpol),
  "LEN_POLARITY",		"RISING_EDGE",
  PCD_LEN_ACT_HIGH,		OFFSET(lenpol),
  "FEN_ENABLE",			"DISABLE",
  PCD_DISABLE,			OFFSET(fenenb),
  "FEN_ENABLE",			"ENABLE",
  PCD_ENABLE,			OFFSET(fenenb),
  "FEN_POLARITY",		"FALLING_EDGE",
  PCD_FEN_ACT_LOW,		OFFSET(fenpol),
  "FEN_POLARITY",		"RISING_EDGE",
  PCD_FEN_ACT_HIGH,		OFFSET(fenpol),
  "MULTI_ENABLE",		"DISABLE",
  PCD_DISABLE,			OFFSET(multenb),
  "MULTI_ENABLE",		"ENABLE",
  PCD_ENABLE,			OFFSET(multenb),
  "MULTI_POLARITY",		"ACTIVE_LOW",
  PCD_MULTI_ACT_LOW,		OFFSET(multpol),
  "MULTI_POLARITY",		"ACTIVE_HIGH",
  PCD_MULTI_ACT_HIGH,		OFFSET(multpol),
  "MULTI_INPUT_MODE",		"MULTI_INPUT_FIELD",
  PCD_MULTI_FIELD,		OFFSET(multmd),
  "MULTI_INPUT_MODE",		"MULTI_INPUT_VALID_DATA",
  PCD_MULTI_DATA_VALID,		OFFSET(multmd),
  "MULTI_INPUT_MODE",		" ",
  PCD_MULTI_EOL,		OFFSET(multmd),
  "RETIME_ENABLE",		"DISABLE",
  PCD_DISABLE,			OFFSET(restime),
  "RETIME_ENABLE",		"ENABLE",
  PCD_ENABLE,			OFFSET(restime),
  "RETIME_POLARITY",		"RISING_EDGE",
  PCD_RESTIME_ACT_HIGH,		OFFSET(respol),
  "RETIME_POLARITY",		"FALLING_EDGE",
  PCD_RESTIME_ACT_LOW,		OFFSET(respol),
  "CAM3_ENABLE",		"DISABLE",
  PCD_DISABLE,			OFFSET(cam3enb),
  "CAM3_ENABLE",		"ENABLE",
  PCD_ENABLE,			OFFSET(cam3enb),
  "EXSYNC_ENABLE",		"DISABLE",
  PCD_DISABLE,			OFFSET(exsenb),
  "EXSYNC_ENABLE",		"ENABLE",
  PCD_ENABLE,			OFFSET(exsenb),
  "EXSYNC_POLARITY",		"ACTIVE_LOW",
  PCD_EXSYNC_ACT_LOW,		OFFSET(exspol),
  "EXSYNC_POLARITY",		"ACTIVE_HIGH",
  PCD_EXSYNC_ACT_HIGH,		OFFSET(exspol),
  "EXSYNC_MODE",		"EXSYNC_FREE_RUNNING",
  PCD_EXSYNC_FREE_RUN,		OFFSET(exsmd),
  "EXSYNC_MODE",		"EXSYNC_TRIG1",
  PCD_EXSYNC_EXT_TRIG0,		OFFSET(exsmd),
  "EXSYNC_MODE",		"EXSYNC_TRIG2",
  PCD_EXSYNC_EXT_TRIG1,		OFFSET(exsmd),
  "EXSYNC_MODE",		"EXSYNC_SOFT_TRIG",
  PCD_EXSYNC_SW_TRIG0,		OFFSET(exsmd),
  "EXSYNC_MODE",		" ",
  PCD_EXSYNC_SW_TRIG1,		OFFSET(exsmd),
  "EXSYNC_MODE",		"EXSYNC_VB_TRIG",
  PCD_EXSYNC_VB_TRIG,		OFFSET(exsmd),
  "PRI_ENABLE",			"DISABLE",
  PCD_DISABLE,			OFFSET(prienb),
  "PRI_ENABLE",			"ENABLE",
  PCD_ENABLE,			OFFSET(prienb),
  "PRI_POLARITY",		"ACTIVE_LOW",
  PCD_PRI_ACT_LOW,		OFFSET(pripol),
  "PRI_POLARITY",		"ACTIVE_HIGH",
  PCD_PRI_ACT_HIGH,		OFFSET(pripol),
  "CCLK_STATIC_ENABLE",		"ENABLE",
  PCD_CCLK_ENABLE,		OFFSET(cclkenb),
  "CCLK_STATIC_ENABLE",		"DISABLE",
  PCD_CCLK_DISABLE,		OFFSET(cclkenb),
  "CCLK_STATIC_STATE",		"LEVEL_LOW",
  PCD_CCLK_STATIC_LOW,		OFFSET(cclkpol),
  "CCLK_STATIC_STATE",		"LEVEL_HIGH",
  PCD_CCLK_STATIC_HIGH,		OFFSET(cclkpol),
  "EXSYNC_START_LOCATION",	" ",
  PCD_EXSSEL_ONE_SHOT,		OFFSET(exssel),
  "EXSYNC_START_LOCATION",	"EXSYNC_START_CYCLE_END",
  PCD_EXSSEL_STRT_TO_MID,	OFFSET(exssel),
  "EXSYNC_START_LOCATION",	"EXSYNC_START_MIDPOINT",
  PCD_EXSSEL_MID_TO_STOP,	OFFSET(exssel),
  "PRI_START_LOCATION", 	" ",
  PCD_PRISEL_ONE_SHOT,		OFFSET(prisel),
  "PRI_START_LOCATION", 	"PRI_START_CYCLE_END",
  PCD_PRISEL_STRT_TO_MID,	OFFSET(prisel),
  "PRI_START_LOCATION", 	"PRI_START_MIDPOINT",
  PCD_PRISEL_MID_TO_STOP,	OFFSET(prisel),
  "PRI_END_LOCATION",		"PRI_END_IS_START_DEPEND",
  PCD_PRIHOLD_NONE,		OFFSET(prihold),
  "PRI_END_LOCATION",		" ",
  PCD_PRIHOLD_LEN_STRT,		OFFSET(prihold),
  "PRI_END_LOCATION",		" ",
  PCD_PRIHOLD_LEN_STOP,		OFFSET(prihold),
  "TRIG_DIVIDE_CONTROL",	"DISABLE_TRIG_DIVIDE",
  PCD_DIVCON_CLEAR,		OFFSET(divcon),
  "TRIG_DIVIDE_CONTROL",	"DIVIDE_TRIG0",
  PCD_DIVCON_TRIG0,		OFFSET(divcon),
  "TRIG_DIVIDE_CONTROL",	"DIVIDE_TRIG1",
  PCD_DIVCON_TRIG1,		OFFSET(divcon),
  "IMAGE_GEOMETRY",		"1CHAN_L2R",
  PCD_1CHAN_L2R,		OFFSET(geometry),
  "IMAGE_GEOMETRY",		"2CHAN_INTERLEAVED",
  PCD_2CHAN_INTERLEAVED,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"2CHAN_SEP_TAP_L2R",
  PCD_2CHAN_SEP_TAP_L2R,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"2CHAN_SEP_TAP_R2L",
  PCD_2CHAN_SEP_TAP_R2L,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"4CHAN_SEP_TAP_L2R",
  PCD_4CHAN_SEP_TAP_L2R,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"4CHAN_SEP_TAP_R2L",
  PCD_4CHAN_SEP_TAP_R2L,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"4CHAN_2SEG_INTERLEAVED",
  PCD_4CHAN_2SEG_INTERLEAVED,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"4CHAN_INTERLEAVE_CONVERGE",
  PCD_4CHAN_INTERLEAVE_CONVERGE,OFFSET(geometry),
  "IMAGE_GEOMETRY",		"2CHAN_SEP_TAP_CONVERGE",
  PCD_2CHAN_SEP_TAP_CONVERGE,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"SEP_QUAD_TAP_CONVERGE",
  PCD_SEP_QUAD_TAP_CONVERGE,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"2TAP_INTERLINE_A_EVEN",
  PCD_2TAP_INTERLINE_A_EVEN,	OFFSET(geometry),
  "IMAGE_GEOMETRY",		"2TAP_INTERLINE_B_EVEN",
  PCD_2TAP_INTERLINE_B_EVEN,	OFFSET(geometry),
  /* double */
  "TRIGGER_POLARITY",		"FALLING_EDGE",
  PCD_TRIG_ACT_LOW,		OFFSET(trig0pol),
  "TRIGGER_POLARITY",		"RISING_EDGE",
  PCD_TRIG_ACT_HIGH,		OFFSET(trig0pol),
  "TRIGGER_SRC",		"DIFFERENTIAL_TRIG",
  PCD_TRIG_SRC_DIFF,		OFFSET(trig0src),
  "TRIGGER_SRC",		"TTL_TRIG",
  PCD_TRIG_SRC_TTL,		OFFSET(trig0src),
  "TRIGGER_SRC",		"OPTO_COUPLED_TRIG",
  PCD_TRIG_SRC_OPTO,		OFFSET(trig0src),
  "TRIG_GLITCH_DETECTOR",	"DISABLE",
  PCD_DISABLE,			OFFSET(trig0gd),
  "TRIG_GLITCH_DETECTOR", 	"ENABLE",
  PCD_ENABLE,			OFFSET(trig0gd),
  '\0',				'\0',
  0,				0
};
#undef OFFSET

const struct iti_cnf_num_t vs_cnf_num[] =
{
  "Strobe_Delay",
  "Horizontal_Offset",
  "Horizontal_Active",
  "Vertical_Offset",
  "Vertical_Active",
  "FRESET_Duration",
  "Clamping_Offset",
  "Video_N_Ref",
  "Video_P_Ref",
  '\0'
};

#ifdef DEBUG_ITIFG
const struct iti_cnf_num_debug_t vs_cnf_num_debug[] =
{
  "strbdly",	"Strobe Delay",
  "hoff   ",	"Horizontal Offset",
  "hsz    ",	"Horizontal Size",
  "voff   ",	"Vertical Offset",
  "vsz    ",	"Vertical Size",
  "froff  ",	"Frame Reset Offset",
  "cppos  ",	"Clamp Position",
  "nref   ",	"Negative Reference Voltage",
  "pref   ",	"Positive Reference Voltage"
};
#endif /* DEBUG_ITIFG */

const struct iti_cnf_num_t dg_cnf_num[] =
{
  "Camera_Mode",
  "EXSCLK_CounterPreset",
  "Horizontal_Offset",
  "Horizontal_Active",
  "Vertical_Offset",
  "Vertical_Active",
  '\0'
};

#ifdef DEBUG_ITIFG
const struct iti_cnf_num_debug_t dg_cnf_num_debug[] =
{
  "mc     ",	"Camera Mode",
  "extime ",	"External Sync Time",
  "hoff   ",	"Horizontal Offset",
  "hact   ",	"Horizontal Active",
  "voff   ",	"Vertical Offset",
  "vact   ",	"Vertical Active",
};
#endif /* DEBUG_ITIFG */

const struct iti_cnf_num_t pv_cnf_num[] =
{
  "HTotal",
  "HSync_Low",
  "HEqual_End",
  "Serration_Total",
  "VTotal",
  "VSync_Low",
  "VGate_Start",
  "VGate_End",
  "HOffset",
  "HActive",
  "VOffset",
  "VActive",
  "Strobe_Delay",
  "FRST_Offset_Delay",
  "Clamp_Delay",
  "PRef",
  "NRef",
  "PLL_FDIV",
  "PLL_RDIV",
  "PLL_VCO",
  "PLL_PDA",
  "PLL_LCOUNT",
  '\0'
};

#ifdef DEBUG_ITIFG
const struct iti_cnf_num_debug_t pv_cnf_num_debug[] =
{
  "HTotal",		"Horizontal Line Rate",
  "HSync_Low",		"Horizontal Sync Low End",
  "HEqual_End",		"Horizontal Equalization Pulse End",
  "Serration_Total",	"Serration Pulse End",
  "VTotal",		"Vertical Sync Total",
  "VSync_Low",		"Vertical Sync",
  "VGate_Start",	"Vertical Gate Start",
  "VGate_End",		"Vertical Gate End",
  "HOffset",		"Horizontal Offset",
  "HActive",		"Horizontal Active",
  "VOffset",		"Vertical Offset",
  "VActive",		"Vertical Active",
  "Strobe_Delay",	"Strobe Delay",
  "FRST_Offset_Delay",	"Frame Reset Delay",
  "Clamp_Delay",	"Clamp Delay Count",
  "PRef",		"Positive Reference",
  "NRef",		"Negative Reference"
  "PLL_FDIV",		"FeedBack Divider",
  "PLL_RDIV",		"Reference Divider",
  "PLL_VCO",		"VCO Gain",
  "PLL_PDA",		"Output Post Scaler",
  "PLL_LCOUNT",		"Load Counter",
};
#endif /* DEBUG_ITIFG */

const struct iti_cnf_num_t pcd_cnf_num[] =
{
  /* integer */
  "CAM_MODE_CTL",
  "HORZ_OFF",
  "WIDTH_PIXELS",
  "VERT_OFF",
  "HEIGHT_PIXELS",
  "PIXEL_SIZE",
  "TRIG_DIVIDE_FACTOR",
  /* float */
  "EXT_SYNC_PERIOD_TIME",
  "CCLK_FREQ_SEL",
  "EXSYNC_MIDPOINT_DELAY",
  "PRI_MIDPOINT_DELAY",
  '\0'
};

#ifdef DEBUG_ITIFG
const struct iti_cnf_num_debug_t pcd_cnf_num_debug[] =
{
  /* integer */
  "CAM_MODE_CTL",		"Camera Mode Control",
  "HORZ_OFF",			"Horizontal Offset",
  "WIDTH_PIXELS",		"Image Width",
  "VERT_OFF",			"Vertical Offset",
  "HEIGHT_PIXELS",		"Image Height",
  "PIXEL_SIZE",			"Pixel Size",
  "TRIG_DIVIDE_FACTOR",		"Trigger Divider Factor",
  /* float */
  "EXT_SYNC_PERIOD_TIME",	"Camera Exposure Time",
  "CCLK_FREQ_SEL",		"Camera Clock Frequency Select",
  "PRI_MIDPOINT_DELAY",		"Camera Readout Time",
  "EXSYNC_MIDPOINT_DELAY",	"Camera Readout Time"
};
#endif /* DEBUG_ITIFG */

#endif /* __CONFIG__ */

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* _ITICONFIG_H */

